/*
  Copyright (c) 2000,2001 Al Sutton (al@alsutton.com)
  All rights reserved.
  Redistribution and use in source and binary forms, with or without modification, are permitted
  provided that the following conditions are met:

  1. Redistributions of source code must retain the above copyright notice, this list of conditions
  and the following disclaimer.

  2. Redistributions in binary form must reproduce the above copyright notice, this list of
  conditions and the following disclaimer in the documentation and/or other materials provided with
  the distribution.

  Neither the name of AlSutton.com nor the names of its contributors may be used to endorse or promote
  products derived from this software without specific prior written permission.

  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS'' AND ANY EXPRESS OR
  IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
  FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE
  LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
  (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA,
  OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
  CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF
  THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/

package com.alsutton.filesync;

import java.io.*;

/**
 * Class to send data to a synchronization endpoint.
 */

public class Synchronizer
{
  /**
   * The stream to the other server.
   */

  private OutputStream outputStream;

  /**
   * The stream from the other server.
   */

  private InputStream inputStream;

  /**
   * The base to receive to
   */

  private String base;

  /**
   * Constructor. Sets the input and output streams to talk to the other end.
   *
   * @param _inputStream A stream from the other synchronizer.
   * @param _outputStream A stream to the other synchronizer.
   */

  public Synchronizer( String _base, InputStream _inputStream, OutputStream _outputStream )
  {
    base = _base;
    inputStream = _inputStream;
    outputStream = _outputStream;
  }

  /**
   * Method to handle a directory
   */

  private void handleDirectory( String base, File directory )
    throws IOException
  {
    String directoryStart = directory.getAbsolutePath();
    String relativePortion = directoryStart.substring( base.length() );

    String[] filenames = directory.list();
    if( filenames == null )
      return;

    for( int i = 0 ; i < filenames.length ; i++ )
    {
      String filename = relativePortion + File.separatorChar + filenames[i];
      sendData( filename );
    }
  }

  /**
   * Method to synchronize a file with the other end.
   *
   * @param base The base for all the synchronization.
   * @param filename The name of the file to synchronize.
   * @param inputStream The stream for data comming from the end point.
   * @param outputStream The stream for data going to the end point.
   */

  public void sendData( String filename )
    throws IOException
  {
    String fullFilename = base + filename;
    File theFile = new File( fullFilename );

    InformationHandler.writeData( base, theFile, inputStream, outputStream );

    if( theFile.isDirectory() )
    {
      handleDirectory( base, theFile );
    }

    System.out.println( "."+filename + " synchronized." );
  }

  /**
   * Method to send the end of tranmission marker
   */

  public void sendEndOfTransmittion()
    throws IOException
  {
    InformationHandler.sendEnd( inputStream, outputStream );
  }
}